@@ -606,6 +606,15 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.SHAKE)
         return self
 
+    def touch_id(self, match):
+        """Do a fingerprint scan
+        """
+        data = {
+            'match': match
+        }
+        self.execute(Command.TOUCH_ID, data)
+        return self
+
     def open_notifications(self):
         """Open notification shade in Android (API Level 18 and above)
         """
@@ -784,6 +793,8 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/appium/device/lock')
         self.command_executor._commands[Command.SHAKE] = \
             ('POST', '/session/$sessionId/appium/device/shake')
+        self.command_executor._commands[Command.TOUCH_ID] = \
+            ('POST', '/session/$sessionId/appium/simulator/touch_id')
         self.command_executor._commands[Command.RESET] = \
             ('POST', '/session/$sessionId/appium/app/reset')
         self.command_executor._commands[Command.HIDE_KEYBOARD] = \
